@@ -28,17 +28,27 @@ data(transfers)
 ##
 ## Case 1
 ##
-load(file=system.file("extdata", "ns.rda", package="EpiContactTrace"))
+load(file = system.file("extdata", "ns.rda", package = "EpiContactTrace"))
 root <- sort(unique(c(transfers$source, transfers$destination)))
-result <- NetworkSummary(transfers, root=root, tEnd='2005-10-31', days=90)
+result <- NetworkSummary(transfers, root = root, tEnd = "2005-10-31", days = 90)
 stopifnot(identical(result, ns))
 
 ##
 ## Case 2
 ##
-ns <- NetworkSummary(transfers, root=584, tEnd='2005-10-31', days=91)
+ns <- NetworkSummary(transfers, root = 584, tEnd = "2005-10-31", days = 91)
 ns.trace <- NetworkSummary(Trace(transfers,
-                                 root=584,
-                                 tEnd='2005-10-31',
-                                 days=91))
+                                 root = 584,
+                                 tEnd = "2005-10-31",
+                                 days = 91))
 stopifnot(identical(ns, ns.trace))
+
+##
+## Case 3
+##
+root <- c(2645, 2838)
+tEnd <- "2005-10-31"
+days <- 90
+contactTrace <- Trace(transfers, root, tEnd, days)
+NetworkSummary(contactTrace)
+NetworkStructure(contactTrace)
